"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGreaterVersion = exports.checkValid = exports.calculateNextIncrementLevel = exports.getHigherIncrementLevel = exports.isValidIncrementLevel = void 0;
const _ = require("lodash");
const semver = require("balena-semver");
const VALID_INCREMENT_LEVELS = ['patch', 'minor', 'major'];
const isValidIncrementLevel = (level) => {
    return _.includes(VALID_INCREMENT_LEVELS, level.toLowerCase());
};
exports.isValidIncrementLevel = isValidIncrementLevel;
const getHigherIncrementLevel = (firstLevel, secondLevel) => {
    _.each([firstLevel, secondLevel], (level) => {
        if (level != null && !(0, exports.isValidIncrementLevel)(level)) {
            throw new Error(`Invalid increment level: ${level}`);
        }
    });
    if (!firstLevel && !secondLevel) {
        return null;
    }
    const firstLevelIndex = _.indexOf(VALID_INCREMENT_LEVELS, firstLevel === null || firstLevel === void 0 ? void 0 : firstLevel.toLowerCase());
    const secondLevelIndex = _.indexOf(VALID_INCREMENT_LEVELS, secondLevel === null || secondLevel === void 0 ? void 0 : secondLevel.toLowerCase());
    return VALID_INCREMENT_LEVELS[Math.max(firstLevelIndex, secondLevelIndex)];
};
exports.getHigherIncrementLevel = getHigherIncrementLevel;
const calculateNextIncrementLevel = (commits, options) => {
    if (_.isEmpty(commits)) {
        throw new Error('No commits to calculate the next increment level from');
    }
    return _.reduce(commits, (currentLevel, commit) => {
        const commitLevel = options.getIncrementLevelFromCommit(commit);
        return (0, exports.getHigherIncrementLevel)(commitLevel, currentLevel);
    }, null);
};
exports.calculateNextIncrementLevel = calculateNextIncrementLevel;
const checkValid = (version) => {
    if (!semver.valid(version)) {
        throw new Error(`Invalid version: ${version}`);
    }
    return true;
};
exports.checkValid = checkValid;
const getGreaterVersion = (versions) => {
    return _.first(versions
        .map((v) => {
        return v.trim();
    })
        .sort(semver.rcompare));
};
exports.getGreaterVersion = getGreaterVersion;
__exportStar(require("balena-semver"), exports);
//# sourceMappingURL=semver.js.map