"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseFooterTagLines = exports.parseTagLine = exports.isTagLine = void 0;
const _ = require("lodash");
const isTagLine = (line) => {
    return _.some([
        /^[\w-]+(\s+)?:[^//]/.test(line),
        /^[\w-]+(\s+)?:$/.test(line),
    ]);
};
exports.isTagLine = isTagLine;
const parseTagLine = (line) => {
    const firstColonIndex = _.indexOf(line, ':');
    return {
        key: line.slice(0, firstColonIndex).trim(),
        value: line.slice(firstColonIndex + 1).trim() || undefined,
    };
};
exports.parseTagLine = parseTagLine;
const parseFooterTagLines = (footerTagLines, options = {}) => {
    return _.chain(footerTagLines)
        .reject((line) => {
        line = line.trim();
        return (_.isEmpty(line) ||
            /^\(cherry\spicked\sfrom\scommit\s[0-9a-f]{7,40}\)$/.test(line));
    })
        .reduce((tags, tagLine) => {
        const tag = (0, exports.parseTagLine)(tagLine);
        tags.push([tag.key, tag.value]);
        if (options.lowerCaseFooterTags) {
            tags.push([tag.key.toLowerCase(), tag.value]);
        }
        return tags;
    }, [])
        .fromPairs()
        .value();
};
exports.parseFooterTagLines = parseFooterTagLines;
//# sourceMappingURL=tags.js.map